<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="title"
        width="50%"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.rules"   label-width="120" >
        <el-row :gutter="24">
          <el-col :span="24">
            <el-form-item label="企业名称:" prop="companyId" v-if="state.isAdmin">
              <el-select v-model="state.form.companyId" placeholder="请选择" clearable style="width: 100%" :disabled="title == '查看' || title == '编辑' || !state.isAdmin" @change="selectValueCom">
                <el-option
                    v-for="item in state.companyList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id">
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="24">
            <el-form-item label="质量目标:" prop="qualityId" >
              <el-select
                  :disabled="title === '查看' || title == '编辑'"
                  v-model="state.form.qualityId"
                  placeholder="请选择质量目标"
                  style="width: 100%"
                  @change="chooseQuality"
              >
                <el-option
                    v-for="item in state.qualityList"
                    :key="item.id"
                    :label="item.message"
                    :value="item.id"
                />
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="12">
            <el-form-item label="序号:" prop="serial" >
              <el-input :disabled="title === '查看'" v-model="state.form.serial" placeholder="请输入序号" style="width: 100%"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="考核时机:" prop="frequency" >
              <el-select
                  :disabled="title === '查看'"
                  v-model="state.form.frequency"
                  placeholder="请选择年份"
                  style="width: 240px"
              >
                <el-option
                    v-for="item in state.frequencyList"
                    :key="item.value"
                    :label="item.label"
                    :value="item.label"
                />
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="24">
            <el-form-item :label="state.type == 1 ? '公司质量目标:' : '部门质量目标:'" required>
              <el-input disabled type="textarea" v-model="state.message" :rows="4"  style="width: 100%"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="24">
            <el-form-item :label="state.type == 1 ? '公司质量目标完成情况:' : '部门质量目标完成情况:'" prop="accomplish" >
              <el-input :disabled="title === '查看'" type="textarea" v-model="state.form.accomplish" :rows="4"  style="width: 100%"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="24">
            <el-form-item label="未完成质量目标的原因分析及制定的纠正措施：" prop="measure" >
              <el-input :disabled="title === '查看'" type="textarea" v-model="state.form.measure" :rows="4"  style="width: 100%"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="24">
            <el-form-item label="对质量管理体系的改进建议：" prop="opinion" >
              <el-input :disabled="title === '查看'" type="textarea" v-model="state.form.opinion" :rows="4"  style="width: 100%"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="12">
            <el-form-item :label="state.type == 1 ? '公司负责人:' : '部门负责人:'" prop="chargeId" >
              <el-select clearable v-model="state.form.chargeId" :disabled="title =='查看'" filterable  style="width: 100%">
                <el-option
                    v-for="item in state.peopleList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id"
                />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="日期:" prop="chargeTime" >
              <el-date-picker
                  :disabled="title === '查看'"
                  v-model="state.form.chargeTime"
                  type="date"
                  placeholder="请选择日期"
              />
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <template #footer v-if="title !== '查看'">
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {onMounted, reactive, ref, toRefs} from 'vue'
import Cookies from "js-cookie";
import {getCompany} from "@/api/onlineEducation/company";
import {ElMessage} from "element-plus";
import {getUser} from "@/api/onlineEducation/user";
import {getObject, getObjectPage} from "@/api/qualityObjectives/object";
import {addTable, editTable, getTargetById} from "@/api/qualityObjectives/table";
import {addReport, editReport} from "@/api/qualityObjectives/reportsituation";

const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);
const dataRef = ref();
const state = reactive({
  form: {
    id: '',
    qualityId: '',
    serial: '',
    frequency: '',
    accomplish : '',
    measure: '',
    opinion:'',
    chargeId :'',
    chargeName: '',
    chargeTime:'',
    qualityTargets:[],
  },
  rules: {
    companyId: [{ required: true, message: '请选择企业', trigger: 'blur' }],
    qualityId: [{ required: true, message: '请选择质量目标', trigger: 'blur' }],
    serial: [{ required: true, message: '请输入序号', trigger: 'blur' }],
    chargeId: [{ required: true, message: '请选择负责人', trigger: 'blur' }],
    chargeTime: [{ required: true, message: '请选择日期', trigger: 'blur' }],
    accomplish:[{ required: true, message: '请输入质量目标完成情况', trigger: 'blur' }],
    frequency:[{ required: true, message: '请选择考核时机', trigger: 'blur' }],
  },
  objectList: [],
  qualityList: [],
  peopleList: [],
  type: null,
  isAdmin: false,
  companyList: [],
  frequencyList: [
    {
      value: 1,
      label: '月'
    },
    {
      value: 2,
      label: '季度'
    },
    {
      value: 3,
      label: '年终'
    },
    {
      value: 4,
      label: '年底'
    },
  ],
  message: ''
})

onMounted(() => {


});
const openDialog = async (type, isCom, value,companyList) => {

  const userInfo = JSON.parse(Cookies.get('userInfo'))
  state.isAdmin = userInfo.userType === 0;
  state.form.companyName = userInfo.companyName
  state.form.companyId = userInfo.companyId
  state.type = isCom == 'company' ? 1 : 2
  if(state.isAdmin){
    state.form.companyId = value.companyId
    state.form.companyName = value.companyName
    state.companyList = companyList
  }
  await getQualityList()
  title.value = type === 'add' ? '新增' : type ==='edit' ? '编辑' : '查看' ;
  if(type === 'edit' || type === 'review') {
    state.form = JSON.parse(JSON.stringify(value));
    chooseQuality(state.form.qualityId)
  }

  await   getPeopleList()
  dialogVisible.value = true;
}

const getQualityList = async () => {
  if(state.form.companyId){
    const res = await getObject({companyId:state.form.companyId,type: state.type });
    if(res.code === 200){
      state.qualityList = res.data.data.map(item => {
        return {
          ...item,
          message: item.qualityTargets.map((i,index) => {
            return  i.message
          }).join(';')
        }
      })

    }else{
      ElMessage.warning(res.message)
    }
  }else {
    state.qualityList = []
  }


}
const onSubmit = async () => {
  const valid = await busRef.value.validate();
  if(valid){
    if(title.value === '新增'){
      console.log('sta',state.form)
      const {id, ...data} = JSON.parse(JSON.stringify(state.form))
      const res = await addReport(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '新增成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }else if(title.value === '编辑'){
      const {...data} = JSON.parse(JSON.stringify(state.form))
      const res = await editReport(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '编辑成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }
  }
}

const handleClose = () => {
  busRef.value.clearValidate();
  reset();
  dialogVisible.value = false;
  emit("getList")

}
const reset = () => {
  state.form = {
    id: '',
    qualityId: '',
    serial: '',
    accomplish : '',
    measure: '',
    opinion:'',
    chargeId :'',
    chargeName: '',
    chargeTime:'',
    frequency:'',
    qualityTargets:[],
  }
  state.peopleList = []
  state.message = ''
  state.companyList = []
  state.qualityList = []
}
const getPeopleList = async ()=> {
  if(state.isAdmin && (state.form.companyId == 0 || state.form.companyId == null)){
    return
  }
  const queryParams = {
    pageNum: 1,
    pageSize: 9999,
    companyId: state.form.companyId
  }
  const res = await getUser(queryParams)
  if(res.code == 200){
    state.peopleList = res.data.list?res.data.list:[]
  }else{
    ElMessage.warning(res.message)
  }
};
const selectValue = (val) => {
  state.peopleList.forEach(item => {
    if(item.name === val){
      state.form.chargeId = item.id
    }
  })
}

const chooseQuality = async (val) => {
  state.message = ''
  const res = await getTargetById({qualityId: val})
  if(res.code == 200){
    state.form.qualityTargets = res.data
    res.data.forEach((i,index) => {
      state.message += index+1 +'、' + i.message + '\n'
    })

  }else {
    ElMessage.warning(res.message)
  }
  console.log('val',val)

}
const selectValueCom = (val) => {
  state.form.qualityId = null
  state.qualityList = []
  state.form.qualityTargets = []
  state.message = ''
  state.form.chargeId = null
  state.form.chargeName = ''
  state.companyList.forEach(item => {
    if(item.name === val){
      state.form.companyId = item.id
    }
  })
  getQualityList()
  getPeopleList()
}
const getCompanyList = async (val)=>{
  if(val){
    const queryParams = {
      name: val
    }
    const res = await getCompany(queryParams)
    if (res.code == 200) {
      state.companyList = res.data.list

    } else {
      ElMessage.warning(res.message)
    }
  }else {
    const queryParams = {
      pageSize: 999,
      pageNum: 1,
    }
    const res = await getCompany(queryParams)
    if (res.code == 200) {
      state.companyList = res.data.list
    } else {
      ElMessage.warning(res.message)
    }
  }
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
